@@ -6,8 +6,9 @@ import os.path
 import re
 import shutil
 import sys
+from collections.abc import MutableMapping
 from subprocess import check_call, check_output  # nosec
-from typing import Callable, Dict, List, MutableMapping, Optional, Tuple, cast
+from typing import Callable, Optional, cast
 
 from schema_salad.sourceline import SourceLine
 from spython.main import Client
@@ -28,13 +29,13 @@ from .utils import CWLObjectType, create_tmp_dir, ensure_non_writable, ensure_wr
 # This is a list containing major and minor versions as integer.
 # (The number of minor version digits can vary among different distributions,
 #  therefore we need a list here.)
-_SINGULARITY_VERSION: Optional[List[int]] = None
+_SINGULARITY_VERSION: Optional[list[int]] = None
 # Cached flavor / distribution of singularity
 # Can be singularity, singularity-ce or apptainer
 _SINGULARITY_FLAVOR: str = ""
 
 
-def get_version() -> Tuple[List[int], str]:
+def get_version() -> tuple[list[int], str]:
     """
     Parse the output of 'singularity --version' to determine the flavor and version.
 
@@ -131,9 +132,9 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
         self,
         builder: Builder,
         joborder: CWLObjectType,
-        make_path_mapper: Callable[[List[CWLObjectType], str, RuntimeContext, bool], PathMapper],
-        requirements: List[CWLObjectType],
-        hints: List[CWLObjectType],
+        make_path_mapper: Callable[[list[CWLObjectType], str, RuntimeContext, bool], PathMapper],
+        requirements: list[CWLObjectType],
+        hints: list[CWLObjectType],
         name: str,
     ) -> None:
         """Builder for invoking the Singularty software container engine."""
@@ -141,7 +142,7 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
 
     @staticmethod
     def get_image(
-        dockerRequirement: Dict[str, str],
+        dockerRequirement: dict[str, str],
         pull_image: bool,
         tmp_outdir_prefix: str,
         force_pull: bool = False,
@@ -247,7 +248,7 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
                             dockerRequirement["dockerImageId"] = path
                             found = True
         if (force_pull or not found) and pull_image:
-            cmd = []  # type: List[str]
+            cmd: list[str] = []
             if "dockerPull" in dockerRequirement:
                 if cache_folder:
                     env = os.environ.copy()
@@ -338,7 +339,7 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
         if not bool(shutil.which("singularity")):
             raise WorkflowException("singularity executable is not available")
 
-        if not self.get_image(cast(Dict[str, str], r), pull_image, tmp_outdir_prefix, force_pull):
+        if not self.get_image(cast(dict[str, str], r), pull_image, tmp_outdir_prefix, force_pull):
             raise WorkflowException("Container image {} not found".format(r["dockerImageId"]))
 
         if "CWL_SINGULARITY_CACHE" in os.environ:
@@ -350,7 +351,7 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
         return os.path.abspath(img_path)
 
     @staticmethod
-    def append_volume(runtime: List[str], source: str, target: str, writable: bool = False) -> None:
+    def append_volume(runtime: list[str], source: str, target: str, writable: bool = False) -> None:
         """Add binding arguments to the runtime list."""
         if is_version_3_9_or_newer():
             DockerCommandLineJob.append_volume(runtime, source, target, writable, skip_mkdirs=True)
@@ -364,7 +365,7 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
             runtime.append(vol)
 
     def add_file_or_directory_volume(
-        self, runtime: List[str], volume: MapperEnt, host_outdir_tgt: Optional[str]
+        self, runtime: list[str], volume: MapperEnt, host_outdir_tgt: Optional[str]
     ) -> None:
         if not volume.resolved.startswith("_:"):
             if host_outdir_tgt is not None and not is_version_3_4_or_newer():
@@ -380,7 +381,7 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
 
     def add_writable_file_volume(
         self,
-        runtime: List[str],
+        runtime: list[str],
         volume: MapperEnt,
         host_outdir_tgt: Optional[str],
         tmpdir_prefix: str,
@@ -417,7 +418,7 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
 
     def add_writable_directory_volume(
         self,
-        runtime: List[str],
+        runtime: list[str],
         volume: MapperEnt,
         host_outdir_tgt: Optional[str],
         tmpdir_prefix: str,
@@ -452,7 +453,7 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
                         shutil.copytree(volume.resolved, host_outdir_tgt)
                     ensure_writable(host_outdir_tgt or new_dir)
 
-    def _required_env(self) -> Dict[str, str]:
+    def _required_env(self) -> dict[str, str]:
         return {
             "TMPDIR": self.CONTAINER_TMPDIR,
             "HOME": self.builder.outdir,
@@ -460,7 +461,7 @@ class SingularityCommandLineJob(ContainerCommandLineJob):
 
     def create_runtime(
         self, env: MutableMapping[str, str], runtime_context: RuntimeContext
-    ) -> Tuple[List[str], Optional[str]]:
+    ) -> tuple[list[str], Optional[str]]:
         """Return the Singularity runtime list of commands and options."""
         any_path_okay = self.builder.get_requirement("DockerRequirement")[1] or False
         runtime = [
