@@ -5,12 +5,8 @@ from .util import get_data
 
 def test_default_path() -> None:
     """Error is not raised when default path is not present."""
-    loadingContext, workflowobj, uri = fetch_document(
-        get_data("tests/wf/default_path.cwl")
-    )
-    loadingContext, uri = resolve_and_validate_document(
-        loadingContext, workflowobj, uri
-    )
+    loadingContext, workflowobj, uri = fetch_document(get_data("tests/wf/default_path.cwl"))
+    loadingContext, uri = resolve_and_validate_document(loadingContext, workflowobj, uri)
     loader = loadingContext.loader
     assert loader
     processobj = loader.resolve_ref(uri)[0]
